# rpico Package

rpico is a module which allows control of a Raspberry Pi Pico microcontroller.

## Features

* reading and writing GPIO singly and in groups
* hardware PWM
* callbacks on GPIO level change
* I2C wrapper
* SPI wrapper
* serial link wrapper
